@@ -1,3 +1,4 @@
+import hashlib
 import random
 import string
 import time
@@ -63,14 +64,8 @@ def _generate_job_id() -> str:
 
 
 def _generate_scheduled_job_id(project: str, feature_table_name: str) -> str:
-    scheduled_job_id = f"feast-{project}-{feature_table_name}".replace("_", "-")
-    k8s_res_name_char_limit = 253
-
-    return (
-        scheduled_job_id
-        if len(scheduled_job_id) <= k8s_res_name_char_limit
-        else scheduled_job_id[:k8s_res_name_char_limit]
-    )
+    job_hash = hashlib.md5(f"{project}-{feature_table_name}".encode()).hexdigest()
+    return f"feast-{job_hash}"
 
 
 def _truncate_label(label: str) -> str:
